@@ -1,6 +1,9 @@
 (require :asdf)
 (require :abcl-contrib)
 
+(asdf:make :abcl-asdf)
+(asdf:make :jna)  
+
 (ql:quickload
  '(:cffi :cffi-tests))
 
