@@ -101,7 +101,7 @@
          (cl:concatenate 'string "~&SYSTEM::*COMPILER-DIAGNOSTIC* " format "~&")
          (when args
            args)))
-          
+
 
 (declaim (ftype (function (t) t) verify-load))
 (defun verify-load (classfile &key (force nil))
@@ -696,7 +696,8 @@ interpreted toplevel form, non-NIL if it is 'simple enough'."
 (defun process-toplevel-form (form stream compile-time-too)
   (unless (atom form)
     (let* ((operator (%car form))
-           (handler (get operator 'toplevel-handler)))
+           (handler (if (symbolp operator)
+                        (get operator 'toplevel-handler))))
       (when handler
         (let ((out-form (funcall handler form stream compile-time-too)))
           (when out-form
@@ -880,18 +881,18 @@ COMPILE-FILE was invoked."
                          (*compiler-error-context* form))
                     (when (eq form in)
                       (return))
-                    (cond 
-                      ((>= (length (format nil "~a" form)) 65536)
-                       ;; Following the solution propose here:
-                       ;; see https://github.com/armedbear/abcl/issues/246#issuecomment-698854437
-                       ;; just include the offending interpreted form in the loader
-                       ;; using it instead of the compiled representation
-                       (diag "Falling back to interpreted version of top-level form longer ~
+
+                    (handler-case (process-toplevel-form form out nil)
+                      (compiler-bytecode-length-error ()
+                        ;; Following the solution propose here:
+                        ;; see https://github.com/armedbear/abcl/issues/246#issuecomment-698854437
+                        ;; just include the offending interpreted form in the loader
+                        ;; using it instead of the compiled representation
+                        (diag "Falling back to interpreted version of top-level form longer ~
                               than 65535 bytes")
-                       (write (ext:macroexpand-all form *compile-file-environment*)
-                              :stream out))
-                      (t 
-                       (process-toplevel-form form out nil))))))
+                        (write (ext:macroexpand-all form *compile-file-environment*)
+                                 :stream out)))
+                    )))
               (finalize-fasl-output)
               (dolist (name *fbound-names*)
                 (fmakunbound name)))))))
