@@ -150,6 +150,7 @@
    "STREAM-READ-SEQUENCE"
    "STREAM-WRITE-SEQUENCE"
    "STREAM-FILE-POSITION"
+   "STREAM-ELEMENT-TYPE"
    "FUNDAMENTAL-BINARY-INPUT-STREAM"
    "FUNDAMENTAL-BINARY-OUTPUT-STREAM"))
 
@@ -189,8 +190,9 @@
 (defvar *ansi-file-position* #'cl:file-position)
 
 (defun ansi-streamp (stream)
-  (or (xp::xp-structure-p stream)
-      (funcall *ansi-streamp* stream)))
+  (not
+   (subtypep (class-of stream)
+             'gray-streams::fundamental-stream)))
 
 (defclass fundamental-stream (standard-object stream)
   ((open-p :initform t
@@ -246,6 +248,10 @@
 
 (defclass fundamental-binary-stream (fundamental-stream) ())
 
+(defmethod gray-stream-element-type ((s fundamental-binary-stream))
+  (declare (ignore s))
+  '(unsigned-byte 8))
+
 (defgeneric stream-read-byte (stream))
 (defgeneric stream-write-byte (stream integer))
 
@@ -656,34 +662,34 @@
 (setf (symbol-function 'common-lisp::listen) #'gray-listen)
 
 (dolist (e '((common-lisp::read-char gray-read-char)
-	     (common-lisp::peek-char gray-peek-char)
-	     (common-lisp::unread-char gray-unread-char)
-	     (common-lisp::read-line gray-read-line)
-	     (common-lisp::clear-input gray-clear-input)
-	     (common-lisp::read-char-no-hang gray-read-char-no-hang)
-	     (common-lisp::write-char gray-write-char)
-	     (common-lisp::fresh-line gray-fresh-line)
-	     (common-lisp::terpri gray-terpri)
-	     (common-lisp::write-string gray-write-string)
-	     (common-lisp::write-line gray-write-line)
-	     (sys::%force-output gray-force-output)
-	     (sys::%finish-output gray-finish-output)
-	     (sys::%clear-output gray-clear-output)
-	     (sys::%output-object gray-output-object)
-	     (common-lisp::read-byte gray-read-byte)
-	     (common-lisp::write-byte gray-write-byte)
-	     (common-lisp::stream-column gray-stream-column)
-	     (common-lisp::stream-element-type gray-stream-element-type)
-	     (common-lisp::close gray-close)
-	     (common-lisp::input-stream-p gray-input-stream-p)
-	     (common-lisp::input-character-stream-p gray-input-character-stream-p) ;; # fb 1.01
-	     (common-lisp::output-stream-p gray-output-stream-p)
-	     (common-lisp::open-stream-p gray-open-stream-p)
-	     (common-lisp::streamp gray-streamp)
-	     (common-lisp::read-sequence gray-read-sequence)
-	     (common-lisp::write-sequence gray-write-sequence)
-	     (common-lisp::file-position gray-file-position)
-	     (common-lisp::listen gray-listen)))
+             (common-lisp::peek-char gray-peek-char)
+             (common-lisp::unread-char gray-unread-char)
+             (common-lisp::read-line gray-read-line)
+             (common-lisp::clear-input gray-clear-input)
+             (common-lisp::read-char-no-hang gray-read-char-no-hang)
+             (common-lisp::write-char gray-write-char)
+             (common-lisp::fresh-line gray-fresh-line)
+             (common-lisp::terpri gray-terpri)
+             (common-lisp::write-string gray-write-string)
+             (common-lisp::write-line gray-write-line)
+             (sys::%force-output gray-force-output)
+             (sys::%finish-output gray-finish-output)
+             (sys::%clear-output gray-clear-output)
+             (sys::%output-object gray-output-object)
+             (common-lisp::read-byte gray-read-byte)
+             (common-lisp::write-byte gray-write-byte)
+             (common-lisp::stream-column gray-stream-column)
+             (common-lisp::stream-element-type gray-stream-element-type)
+             (common-lisp::close gray-close)
+             (common-lisp::input-stream-p gray-input-stream-p)
+             (common-lisp::input-character-stream-p gray-input-character-stream-p) ;; # fb 1.01
+             (common-lisp::output-stream-p gray-output-stream-p)
+             (common-lisp::open-stream-p gray-open-stream-p)
+             (common-lisp::streamp gray-streamp)
+             (common-lisp::read-sequence gray-read-sequence)
+             (common-lisp::write-sequence gray-write-sequence)
+             (common-lisp::file-position gray-file-position)
+             (common-lisp::listen gray-listen)))
   (sys::put (car e) 'sys::source (cl:get (second e) 'sys::source)))
 
 #|
